@@ -1,5 +1,5 @@
 use crate::{Axis, Input};
-use bevy_app::{EventReader, EventWriter};
+use bevy_ecs::event::{EventReader, EventWriter};
 use bevy_ecs::system::{Res, ResMut};
 use bevy_utils::{tracing::info, HashMap, HashSet};
 
@@ -279,23 +279,23 @@ pub fn gamepad_event_system(
         match event {
             GamepadEventType::Connected => {
                 events.send(GamepadEvent(gamepad, event.clone()));
-                for button_type in ALL_BUTTON_TYPES.iter() {
+                for button_type in &ALL_BUTTON_TYPES {
                     let gamepad_button = GamepadButton(gamepad, *button_type);
                     button_input.reset(gamepad_button);
                     button_axis.set(gamepad_button, 0.0);
                 }
-                for axis_type in ALL_AXIS_TYPES.iter() {
+                for axis_type in &ALL_AXIS_TYPES {
                     axis.set(GamepadAxis(gamepad, *axis_type), 0.0);
                 }
             }
             GamepadEventType::Disconnected => {
                 events.send(GamepadEvent(gamepad, event.clone()));
-                for button_type in ALL_BUTTON_TYPES.iter() {
+                for button_type in &ALL_BUTTON_TYPES {
                     let gamepad_button = GamepadButton(gamepad, *button_type);
                     button_input.reset(gamepad_button);
                     button_axis.remove(gamepad_button);
                 }
-                for axis_type in ALL_AXIS_TYPES.iter() {
+                for axis_type in &ALL_AXIS_TYPES {
                     axis.remove(GamepadAxis(gamepad, *axis_type));
                 }
             }
@@ -309,7 +309,7 @@ pub fn gamepad_event_system(
                     events.send(GamepadEvent(
                         gamepad,
                         GamepadEventType::AxisChanged(*axis_type, filtered_value),
-                    ))
+                    ));
                 }
             }
             GamepadEventType::ButtonChanged(button_type, value) => {
@@ -322,7 +322,7 @@ pub fn gamepad_event_system(
                     events.send(GamepadEvent(
                         gamepad,
                         GamepadEventType::ButtonChanged(*button_type, filtered_value),
-                    ))
+                    ));
                 }
 
                 let button_property = settings.get_button_settings(gamepad_button);
