@@ -13,7 +13,7 @@ pub fn exit_on_esc_system(
     for event in keyboard_input_events.iter() {
         if let Some(key_code) = event.key_code {
             if event.state == ElementState::Pressed && key_code == KeyCode::Escape {
-                app_exit_events.send(AppExit);
+                app_exit_events.send_default();
             }
         }
     }
